### Load library and set working directory ###
#if (!requireNamespace("BiocManager", quietly = TRUE))
#  install.packages("BiocManager")
#BiocManager::install("edgeR")

library('edgeR')
library(ggfortify)
library(RColorBrewer)
library(reshape2)
library("mclust")
#library(fpc)
setwd("~/Desktop/Documents/Okis/TransgenicEnviroment/Data/RNAseq/")

### Read and format data ###
counts <- read.table("join_count.txt",header=T,na.strings="NA")
rownames(counts)<-counts$genes
counts$genes<-NULL
sampleNames <-c("SW1", "TT1", "TW1", "TT2", "TW2", "ST1", "ST2", "SW2")
colnames(counts) <- sampleNames


##############################################################
### Design ###################################################
##############################################################
### The simple design excludes a intercept column and has a column for each group instead ###
### It will be used so that all analyses are performed with the contrast feature ###
targets <- read.table("design.txt",header=T,na.strings="NA")
rownames(targets) <- sampleNames
targets$genotype <-as.factor(targets$genotype)
targets$environment <-as.factor(targets$environment)
targets$genotype <- relevel(targets$genotype, ref=c("wild"))
targets$environment<- relevel(targets$environment, ref=c("Stream"))
group <-  factor(targets$interaction)
#head(counts)

SimpleDesign <- model.matrix(~0+group, data=targets)
#FactorialDesign <- model.matrix(~genotype*environment, data=targets)
colnames(SimpleDesign) <- levels(group)
#head(FactorialDesign)
#head(SimpleDesign)

### Create edge R nested list ###
y <- DGEList(counts=counts, group=group)
#head(targets)
#head(y$samples)
###############################################################
### Data preparation for statistical analyses #################
###############################################################

### Filter lowly expressed genes ###
keep <- filterByExpr(y)
y <- y[keep, , keep.lib.sizes=FALSE]
### calculate a normalization factor ###
### reduces the effects of a few genes monopolizing the sequencing ###
y <- calcNormFactors(y)
### estimate gene expression dispersion ###
### Used to estimate how much gene expression varies without being significant ###
y <- estimateDisp(y, SimpleDesign)
#yF <- estimateDisp(y, FactorialDesign) ###Output is the same as the simple design if done correctly

allGenesExpression <- as.data.frame(cpm(y))
allGenesExpression$SW <- (allGenesExpression$SW1 + allGenesExpression$SW2)/2
allGenesExpression$TW <- (allGenesExpression$TW1 + allGenesExpression$TW2)/2
allGenesExpression$ST <- (allGenesExpression$ST1 + allGenesExpression$ST2)/2
allGenesExpression$TT <- (allGenesExpression$TT1 + allGenesExpression$TT2)/2
allGenesExpression <- subset(allGenesExpression, select=c('SW', 'TW', 'ST', 'TT'))
allGenesExpression[which(row.names(allGenesExpression) == "LOC109891274"),]
write.table(allGenesExpression, "all.gene.cpm.averaged.csv", sep=",")

### fit the data using quasi likelihood f statistic test ###
fit <- glmQLFit(y, SimpleDesign)
#fitF <- glmQLFit(y, FactorialDesign)

####################################################################
### The research questions are then put into different contrasts ###
####################################################################
### simple comparisons ###
simple.contrasts <- makeContrasts(STvSW=ST-SW,
                                  STvTT=ST-TT,
                                  SWvTW=SW-TW,
                                  TTvTW=TT-TW,
                                  GxE1=(SW-TW)-(ST-TT),
                                  #                                  GxE2=(SW-ST)-(TW-TT),
                                  levels=SimpleDesign)
###GxE1 = genes that have responded differentially between stream and tank based on genotype
###GxE2 = genes that have responded differentially between genotypes based on environment

###################################################################
### Statistical Tests #############################################
###################################################################
STvSW <- glmQLFTest(fit, contrast=simple.contrasts[,"STvSW"])
STvTT <- glmQLFTest(fit, contrast=simple.contrasts[,"STvTT"])
SWvTW <- glmQLFTest(fit, contrast=simple.contrasts[,"SWvTW"])
TTvTW <- glmQLFTest(fit, contrast=simple.contrasts[,"TTvTW"])
GxE1 <- glmQLFTest(fit, contrast=simple.contrasts[,"GxE1"])
#GxE2 <- glmQLFTest(fit, contrast=simple.contrasts[,"GxE2"])
annov <- glmQLFTest(fit, contrast=simple.contrasts)

#fac1 <- glmQLFTest(fitF, coef=4)

###################################################################
### Figures #######################################################
###################################################################
#### MDS Plot for Count Data (log2 of fold change) Top 1000 most Variable genes#### 
colors <- rep(c("blue", "darkgreen", "red", "orange"), 2)
points <- c(15,15,16,16)
plotMDS(y, pch=16, col=colors[group], cex=2, top=100000)
legend("topright", legend=c("Stream Transgenic", "Stream Wild-type", "Tank Transgenic", "Tank Wild-type"), pch=16, col=colors, ncol=1, cex=1.5)
#### PCA plot
#head(y$design)
#PCA <- prcomp(t(y$counts), scale.=T, center=T)
#summary(PCA)
#head(y$counts)
#PCA$x
#ggplot(PCA, aes(PCA$x[,1], PCA$x[,2], color=c(group), cex=2)) + 
#  geom_point() + labs(x="PC1 (35.68%)", y= "PC2 (26.37%)", color="Group") + guides(size=FALSE) + geom_text(aes(label=row.names(PCA$x)), hjust=0,vjust=0)

##################################################################
### Further information on significant DEGs ######################
##################################################################
### STvSW ###
summary(decideTests(STvSW))
decideTests(STvSW)
?decideTests
topTags(STvSW, p.value=0.05)
cpm(y)[order(STvSW$table$PValue)[1:10],]
plotMD(STvSW)
abline(h=c(-1, 1), col="blue")
up <- decideTests(STvSW)[which(decideTests(STvSW) > 0),]
down <- decideTests(STvSW)[which(decideTests(STvSW) < 0),]
all <- decideTests(STvSW)[which(decideTests(STvSW) != 0),]
write.table (names(all), "STvSW.csv", sep=",")

### TTvTW ###
summary(decideTests(TTvTW))
topTags(TTvTW, p.value=0.05)
cpm(y)[order(TTvTW$table$PValue)[1:10],]
plotMD(TTvTW)
abline(h=c(-1, 1), col="blue")
up <- decideTests(TTvTW)[which(decideTests(TTvTW) > 0),]
down <- decideTests(TTvTW)[which(decideTests(TTvTW) < 0),]
all <- decideTests(TTvTW)[which(decideTests(TTvTW) != 0),]
write.table (names(all), "TTvTW.csv", sep=",")

### STvTT ###
summary(decideTests(STvTT))
topTags(STvTT, p.value=0.05)
cpm(y)[order(STvTT$table$PValue)[1:10],]
plotMD(STvTT)
abline(h=c(-1, 1), col="blue")
up <- decideTests(STvTT)[which(decideTests(STvTT) > 0),]
down <- decideTests(STvTT)[which(decideTests(STvTT) < 0),]
all <- decideTests(STvTT)[which(decideTests(STvTT) != 0),]
write.table (names(all), "STvTT.csv", sep=",")

### SWvTW ###
summary(decideTests(SWvTW))
topTags(SWvTW, p.value=0.05)
cpm(y)[order(SWvTW$table$PValue)[1:10],]
plotMD(SWvTW)
abline(h=c(-1, 1), col="blue")
up <- decideTests(SWvTW)[which(decideTests(SWvTW) > 0),]
down <- decideTests(SWvTW)[which(decideTests(SWvTW) < 0),]
all <- decideTests(SWvTW)[which(decideTests(SWvTW) != 0),]
write.table (names(all), "SWvTW.csv", sep=",")

### annov ###
summary(decideTests(annov))
topTags(annov, p.value=0.05)
significantGenesCPM <- as.data.frame(cpm(y)[as.vector(rownames(topTags(annov, p.value=0.05, n=9615)$table)),])
head(significantGenesCPM)
samplesNames <-c("SW1", "TT1", "TW1", "TT2", "TW2", "ST1", "ST2", "SW2")
colnames(significantGenesCPM) <- samplesNames
significantGenesCPM <- as.data.frame(significantGenesCPM)
write.table(significantGenesCPM, "significant.Annova.new.GeneExpression.all.csv", sep=",")

### GxE ###
summary(decideTests(GxE1))
topTags(GxE1, p.value=0.05)
cpm(y)[order(GxE1$table$PValue)[1:10],]
plotMD(GxE1)
abline(h=c(-1, 1), col="blue")
up <- decideTests(GxE1)[which(decideTests(GxE1) > 0),]
down <- decideTests(GxE1)[which(decideTests(GxE1) < 0),]
all <- decideTests(GxE1)[which(decideTests(GxE1) != 0),]
write.table (names(all), "GxE.csv", sep=",")
significantGxECPM <- as.data.frame(cpm(y)[as.vector(rownames(topTags(GxE1, p.value=0.05, n=901)$table)),])
head(significantGxECPM)
heatmap(x=as.matrix(significantGxECPM),col= colorRampPalette(brewer.pal(8, "Blues"))(25))
legend(x="topleft", legend=c("min", "avg.", "max"), 
       fill=colorRampPalette(brewer.pal(8, "Blues"))(3))

#############################################################
### Overlaps ################################################
#############################################################
###Gene
###Pairwise STvSW vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(STvSW)[which(decideTests(STvSW) != 0),])), row.names(as.data.frame(decideTests(STvSW)[which(decideTests(STvSW) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSW)[which(decideTests(STvSW) != 0),])), row.names(as.data.frame(decideTests(TTvTW)[which(decideTests(TTvTW) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSW)[which(decideTests(STvSW) != 0),])), row.names(as.data.frame(decideTests(STvTT)[which(decideTests(STvTT) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSW)[which(decideTests(STvSW) != 0),])), row.names(as.data.frame(decideTests(SWvTW)[which(decideTests(SWvTW) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSW)[which(decideTests(STvSW) != 0),])), row.names(as.data.frame(decideTests(annov)[which(decideTests(annov) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSW)[which(decideTests(STvSW) != 0),])), row.names(as.data.frame(decideTests(GxE1)[which(decideTests(GxE1) != 0),]))))

###Pairwise TTvTW vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(TTvTW)[which(decideTests(TTvTW) != 0),])), row.names(as.data.frame(decideTests(TTvTW)[which(decideTests(TTvTW) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTW)[which(decideTests(TTvTW) != 0),])), row.names(as.data.frame(decideTests(STvTT)[which(decideTests(STvTT) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTW)[which(decideTests(TTvTW) != 0),])), row.names(as.data.frame(decideTests(SWvTW)[which(decideTests(SWvTW) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTW)[which(decideTests(TTvTW) != 0),])), row.names(as.data.frame(decideTests(annov)[which(decideTests(annov) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTW)[which(decideTests(TTvTW) != 0),])), row.names(as.data.frame(decideTests(GxE1)[which(decideTests(GxE1)!= 0),]))))

###Pairwise STvTT vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(STvTT)[which(decideTests(STvTT) != 0),])), row.names(as.data.frame(decideTests(STvTT)[which(decideTests(STvTT) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTT)[which(decideTests(STvTT) != 0),])), row.names(as.data.frame(decideTests(SWvTW)[which(decideTests(SWvTW) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTT)[which(decideTests(STvTT) != 0),])), row.names(as.data.frame(decideTests(annov)[which(decideTests(annov) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTT)[which(decideTests(STvTT) != 0),])), row.names(as.data.frame(decideTests(GxE1)[which(decideTests(GxE1) != 0),]))))

###Pairwise SWvTW vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(SWvTW)[which(decideTests(SWvTW) != 0),])), row.names(as.data.frame(decideTests(SWvTW)[which(decideTests(SWvTW) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTW)[which(decideTests(SWvTW) != 0),])), row.names(as.data.frame(decideTests(annov)[which(decideTests(annov) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTW)[which(decideTests(SWvTW) != 0),])), row.names(as.data.frame(decideTests(GxE1)[which(decideTests(GxE1) != 0),]))))

###Pairwise Anova vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(annov)[which(decideTests(annov) != 0),])), row.names(as.data.frame(decideTests(annov)[which(decideTests(annov) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(annov)[which(decideTests(annov) != 0),])), row.names(as.data.frame(decideTests(GxE1)[which(decideTests(GxE1) != 0),]))))


#############################################################
### Clustering (correlation)  ################################
### Similar to https://bio723-class.github.io/Bio723-book/clustering-in-r.html
#############################################################
###Data structuring
significantGxECPM$ST <- (significantGxECPM$`ST1` + significantGxECPM$`ST2`)/2
significantGxECPM$SW <- (significantGxECPM$`SW1` + significantGxECPM$`SW2`)/2
significantGxECPM$TT <- (significantGxECPM$`TT1` + significantGxECPM$`TT2`)/2
significantGxECPM$TW <- (significantGxECPM$`TW1` + significantGxECPM$`TW2`)/2
significantGxECPM <- subset(significantGxECPM, select=c('ST','SW','TT','TW'))
significantGxECPM <- significantGxECPM[,c(2,4,1,3)]
sGxE <- significantGxECPM
head(sGxE)

rows.cor <- cor(t(sGxE), use = "pairwise.complete.obs", method = "spearman")
hclust.row <- hclust(as.dist(1-rows.cor))
cols.cor <- cor(sGxE, use = "pairwise.complete.obs", method = "spearman")
hclust.col <- hclust(as.dist(1-cols.cor))

library("pheatmap")
pheatmap(
  as.matrix(sGxE), scale = "row", 
  clustering_distance_cols = as.dist(1 - cols.cor),
  clustering_distance_rows = as.dist(1 - rows.cor),
  show_rownames = F
)
library(dendextend)
dendogramCorr <- as.dendrogram(hclust.row)
clusters <- cutree(dendogramCorr, k=24, order_clusters_as_data = TRUE)
dendogramCorr %>% 
  color_branches(k=24, groupLabels = TRUE) %>%
  highlight_branches_lwd %>%
  plot(leaflab="none")

labels(dendogramCorr) ### Order in figure
sGxE$cluster <- clusters
table(clusters)
c1 <- sGxE[which(sGxE$cluster == 11),]
c1$gene <- rownames(c1)
heatmap(x=as.matrix(subset(c1, select=c('SW','TW','ST','TT'))),col= colorRampPalette(brewer.pal(8, "Blues"))(25))
legend(x="topleft", legend=c("min", "avg.", "max"), 
       fill=colorRampPalette(brewer.pal(8, "Blues"))(3))
c1_melt = melt(subset(c1, select=c('SW','TW','ST','TT','gene')), id.vars = 'gene')
ggplot(c1_melt, aes(x=variable, y=log(value))) + 
  geom_line(aes(color=gene, group=gene)) +
  theme_classic() +
  theme(legend.position="none")

write.table (sGxE, "annovaGxEKmeanCluster1.csv", sep=",")


#############################################################
### Growth Hormone Gene Expression Differences ##############
### Needs to be performed before removing low expressed genes
z <- c("LOC109893213","LOC109898300","LOC109877434","LOC109889150",
       "LOC109877853","LOC109892335","LOC109868115","LOC109873840",
       "LOC109896160","LOC109873964", "transgene")
gh <- as.data.frame(cpm(y))[row.names(as.data.frame(cpm(y))) %in% z,]
head(gh, n=22)

#############################################################
### Transposable Elements (PiggyBAC) ########################
x <- c("LOC109902658","LOC109872064","LOC109872199","LOC109906238","LOC109899170","
       LOC109891614","LOC109878482","LOC109875800","LOC109870067","LOC109910161","LOC109906768","
       LOC109905967","LOC109904664","LOC109904587","LOC109898877","LOC109895269","LOC109889549","
       LOC109877893","LOC109876121","LOC109873605","LOC109873580")
piggy <- as.data.frame(cpm(y))[row.names(as.data.frame(cpm(y))) %in% x,]
piggy

#############################################################
### IGF                              ########################
u <- c("igf1","LOC109907930","LOC109896674","LOC109867245")
igf <- as.data.frame(cpm(y))[row.names(as.data.frame(cpm(y))) %in% u,]
igf

#############################################################
### Check for specific genes 
significantGenesCPM["LOC109867245",]
