#BiocManager::install("edgeR")
library("edgeR")
library("readr")
library(tibble)
library(dplyr)
library(tidyr)
library(ggfortify)
library(VennDiagram)
library(RColorBrewer)
library(reshape2)
library("mclust")
setwd("/scratch2/kchristensen/Okis/TransgenicEnvironment/")

######################
### Load the Data ####
######################

targets <- read.delim("targets.txt", header=TRUE, sep=" ")
files <- targets$File
yall <- readBismark2DGE(as.vector(files), sample.names=targets$Sample)

###Filters the mitochondrion
yall <- yall[yall$genes$Chr!="NC_009263.1",]

###The position of all the loci were output ###
###A custom script was used to identify the closest TSS for each position (NA returned if no gene nearby)###
#write.table(yall$counts, "MethylationPositions.txt", sep="\t")
TSS <- read.table("./output/R.TSS.Info.v.1.1.txt",header=F,na.strings="NA")  ###Has information about the closest gene to CpG
yall$genes$EntrezID <- TSS$V2
yall$genes$Symbol <- TSS$V2
yall$genes$Strand <- TSS$V3
yall$genes$Distance <- TSS$V1
yall$genes$Width <- TSS$V4

######################################################
### Subset the data into promoter and gene body ######
### Need to account for the direction of gene ########
######################################################

###Partition positive direction and negative direction
yallNegative <- yall[which(yall$genes$Strand == "-"),]
yallPositive <- yall[which(yall$genes$Strand == "+"),]

###Initially the distances were incorrect for the negative orientation genes, this corrects that issue
yallNegative$genes$NewDistance <- yallNegative$genes$Distance + yallNegative$genes$Width ###Orientation correction
yallPositive$genes$NewDistance <- yallPositive$genes$Distance

###Finds the start of the gene by adding the distance between
yallNegative$genes$GeneStart <- yallNegative$genes$NewDistance + yallNegative$genes$Locus
yallPositive$genes$GeneStart <- yallPositive$genes$NewDistance + yallPositive$genes$Locus

###Finds the end of the gene calculated by the start of the gene, the width, and the orientation
yallNegative$genes$GeneEnd <- yallNegative$genes$GeneStart - yallNegative$genes$Width
yallPositive$genes$GeneEnd <- yallPositive$genes$GeneStart + yallPositive$genes$Width

###Finds the promoter start and end
yallNegative$genes$PromoterStart <- yallNegative$genes$GeneStart + 2000
yallPositive$genes$PromoterStart <- yallPositive$genes$GeneStart - 2000
yallNegative$genes$PromoterEnd <- yallNegative$genes$GeneStart - 1000
yallPositive$genes$PromoterEnd <- yallPositive$genes$GeneStart + 1000

###Split the dataframes into promoter and gene associated markers
yallPromoterPositive <- yallPositive[which(yallPositive$genes$Locus >= yallPositive$genes$PromoterStart & yallPositive$genes$Locus <= yallPositive$genes$PromoterEnd),]
yallPromoterNegative <- yallNegative[which(yallNegative$genes$Locus >= yallNegative$genes$PromoterEnd & yallNegative$genes$Locus <= yallNegative$genes$PromoterStart),]
yallPromoter <- rbind(yallPromoterPositive, yallPromoterNegative)
yallPromoter <- yallPromoter[which(yallPromoter$genes$Locus >= 0),,keep.lib.sizes=FALSE]
rm(yallPromoterPositive, yallPromoterNegative)

### gene associated
yallGenePositive <- yallPositive[which(yallPositive$genes$Locus >= yallPositive$genes$GeneStart & yallPositive$genes$Locus <= yallPositive$genes$GeneEnd),]
yallGeneNegative <- yallNegative[which(yallNegative$genes$Locus >= yallNegative$genes$GeneEnd & yallNegative$genes$Locus <= yallNegative$genes$GeneStart),]
yallGene <- rbind(yallGenePositive, yallGeneNegative)
yallGene <- yallGene[which(yallGene$genes$Locus >= 0),,keep.lib.sizes=FALSE]
rm(yallGenePositive, yallGeneNegative)

###Neither gene or promoter related
yallIntergenicPositive <- yallPositive[which(!(yallPositive$genes$Locus >= yallPositive$genes$PromoterStart & yallPositive$genes$Locus <= yallPositive$genes$GeneEnd)),]
yallIntergenicNegative <- yallNegative[which(!(yallNegative$genes$Locus >= yallNegative$genes$GeneEnd & yallNegative$genes$Locus <= yallNegative$genes$PromoterStart)),]
yallIntergenicNotGenic <- yall[which(!complete.cases(yall$genes)),]
yallIntergenicNotGenic$genes$NewDistance <- NA
yallIntergenicNotGenic$genes$GeneStart <- NA
yallIntergenicNotGenic$genes$GeneEnd <- NA
yallIntergenicNotGenic$genes$PromoterStart <- NA
yallIntergenicNotGenic$genes$PromoterEnd <- NA
yallIntergenic <- rbind(yallIntergenicPositive, yallIntergenicNegative, yallIntergenicNotGenic)
rm(yallIntergenicPositive, yallIntergenicNegative, yallIntergenicNotGenic)

###remove old datasets
rm(yall, yallNegative, yallPositive)

####################################
### Design #########################
####################################
head(targets)
group <-factor(targets$Group)
SimpleDesign <- model.matrix(~0+group, data=targets)
design <- modelMatrixMeth(SimpleDesign)

####################################
### Total count for a gene or ######
### a promoter #####################
####################################
yPromoter <- rowsum(yallPromoter, yallPromoter$genes$EntrezID, reorder=FALSE)
yPromoter$genes$EntrezID <- NULL

yGene <- rowsum(yallGene, yallGene$genes$EntrezID, reorder=FALSE)
yGene$genes$EntrezID <- NULL

####################################
### Filter Low Coverage ############
####################################
Methylation <- gl(2,1,ncol(yPromoter), labels=c("Me","Un"))
Mepr <- yPromoter$counts[,Methylation=="Me"]
Unpr <- yPromoter$counts[,Methylation=="Un"]
CoveragePromoter <- Mepr + Unpr
HasCoveragePromoter <- rowSums(CoveragePromoter >= 5) == 8
HasBothPromoter <- rowSums(Mepr) > 0 & rowSums(Unpr) > 0
table(HasCoveragePromoter, HasBothPromoter)
yPromoter <- yPromoter[HasCoveragePromoter & HasBothPromoter,,keep.lib.sizes=FALSE]

Methylation <- gl(2,1,ncol(yGene), labels=c("Me","Un"))
Mege <- yGene$counts[,Methylation=="Me"]
Unge <- yGene$counts[,Methylation=="Un"]
CoverageGene <- Mege + Unge
HasCoverageGene <- rowSums(CoverageGene >= 5) == 8
HasBothGene <- rowSums(Mege) > 0 & rowSums(Unge) > 0
table(HasCoverageGene, HasBothGene)
yGene <- yGene[HasCoverageGene & HasBothGene,,keep.lib.sizes=FALSE]

Methylation <- gl(2,1,ncol(yallIntergenic), labels=c("Me","Un"))
Me <- yallIntergenic$counts[, Methylation=="Me"]
Un <- yallIntergenic$counts[, Methylation=="Un"]
Coverage <- Me + Un
HasCoverage <- rowSums(Coverage >= 5) == 8
HasBoth <- rowSums(Me) > 0 & rowSums(Un) > 0
table(HasCoverage, HasBoth)
yIntergenic <- yallIntergenic[HasCoverage & HasBoth,, keep.lib.sizes=FALSE]

rm(yallGene, yallIntergenic, yallPromoter, HasBoth, HasBothGene, HasBothPromoter, HasCoverage, HasCoverageGene)
rm(HasCoveragePromoter, Methylation, Mepr, Unpr, Mege, Unge)

###################################################
### Set same scale for meth and unmeth ############
###################################################

Methylation <- gl(2,1,ncol(yPromoter), labels=c("Me","Un"))
TotalLibSize <- 0.5*yPromoter$samples$lib.size[Methylation=="Me"] +
  0.5*yPromoter$samples$lib.size[Methylation=="Un"]
yPromoter$samples$lib.size <- rep(TotalLibSize, each=2)

Methylation <- gl(2,1,ncol(yGene), labels=c("Me","Un"))
TotalLibSize <- 0.5*yGene$samples$lib.size[Methylation=="Me"] +
  0.5*yGene$samples$lib.size[Methylation=="Un"]
yGene$samples$lib.size <- rep(TotalLibSize, each=2)

Methylation <- gl(2,1,ncol(yIntergenic), labels=c("Me","Un"))
TotalLibSize <- yIntergenic$samples$lib.size[Methylation=="Me"] +
  yIntergenic$samples$lib.size[Methylation=="Un"]
yIntergenic$samples$lib.size <- rep(TotalLibSize, each=2)

##########################################################################################
### Visualizing before finding differentially methylated parts of the genome #############
##########################################################################################

### MDS plot (Need to have the right methylation above)
Methylation <- gl(2,1,ncol(yPromoter), labels=c("Me","Un"))
Me <- yPromoter$counts[,Methylation=="Me"]
Un <- yPromoter$counts[,Methylation=="Un"]
Mpromoter <- log2(Me + 2) - log2(Un + 2)
colnames(Mpromoter) <- targets$Sample
Names <- c("Stream Transgenic", "Stream Wild-type", "Tank Transgenic", "Tank Wild-type")
colors <- c("blue", "blue", "darkgreen", "darkgreen", "red", "red", "orange", "orange")
plotMDS(Mpromoter, cex=2, top=100000000, col=colors[targets$Sample], pch=16)
legend("bottom", legend=Names, pch=16, col=c("blue","darkgreen","red","orange"), cex=1)

Methylation <- gl(2,1,ncol(yGene), labels=c("Me","Un"))
Me <- yGene$counts[,Methylation=="Me"]
Un <- yGene$counts[,Methylation=="Un"]
Mgene <- log2(Me + 2) - log2(Un + 2)
colnames(Mgene) <- targets$Sample
Names <- c("Stream Transgenic", "Stream Wild-type", "Tank Transgenic", "Tank Wild-type")
colors <- c("blue", "blue", "darkgreen", "darkgreen", "red", "red", "orange", "orange")
plotMDS(Mgene, cex=2, top=100000000, col=colors[targets$Sample], pch=16)
legend("center", legend=Names, pch=16, col=c("blue","darkgreen","red","orange"), cex=1)

Methylation <- gl(2,1,ncol(yIntergenic), labels=c("Me","Un"))
Me <- yIntergenic$counts[,Methylation=="Me"]
Un <- yIntergenic$counts[,Methylation=="Un"]
Mintergenic <- log2(Me + 2) - log2(Un + 2)
colnames(Mintergenic) <- targets$Sample
Names <- c("Stream Transgenic", "Stream Wild-type", "Tank Transgenic", "Tank Wild-type")
colors <- c("blue", "blue", "darkgreen", "darkgreen", "red", "red", "orange", "orange")
plotMDS(Mintergenic, cex=2, top=100000000, col=colors[targets$Sample], pch=16)
legend("top", legend=Names, pch=16, col=c("blue","darkgreen","red","orange"), cex=1)


##########################################################################################
### Differential methylation                   ###########################################
##########################################################################################
### Estimating Dispersion
yPromoter <- estimateDisp(yPromoter, design, trend="none")
yGene <- estimateDisp(yGene, design, trend="none")
yIntergenic <- estimateDisp(yIntergenic, design, trend="none")

### Fit GLMs for all gene promoters
fitPromoter <- glmFit(yPromoter, design)
fitGene <- glmFit(yGene, design)
fitIntergenic <- glmFit(yIntergenic, design)

#####################################################
### Compare individual groups or all together #######
#####################################################

### Pairwise Comparisons ###
pairwise.contrasts <- makeContrasts(STvSW=groupST-groupSW,
                                    STvTT=groupST-groupTT,
                                    SWvTW=groupSW-groupTW,
                                    TTvTW=groupTT-groupTW,
                                    GxE=(groupSW-groupTW)-(groupST-groupTT),
                                    levels=design)

### For promoter, gene, and intergenic ###
STvSWpromoter <- glmLRT(fitPromoter, contrast=pairwise.contrasts[,"STvSW"])
STvTTpromoter <- glmLRT(fitPromoter, contrast=pairwise.contrasts[,"STvTT"])
SWvTWpromoter <- glmLRT(fitPromoter, contrast=pairwise.contrasts[,"SWvTW"])
TTvTWpromoter <- glmLRT(fitPromoter, contrast=pairwise.contrasts[,"TTvTW"])
GxEpromoter <- glmLRT(fitPromoter, contrast=pairwise.contrasts[,"GxE"])
annovPromoter <- glmLRT(fitPromoter, contrast=pairwise.contrasts)

STvSWgene <- glmLRT(fitGene, contrast=pairwise.contrasts[,"STvSW"])
STvTTgene <- glmLRT(fitGene, contrast=pairwise.contrasts[,"STvTT"])
SWvTWgene <- glmLRT(fitGene, contrast=pairwise.contrasts[,"SWvTW"])
TTvTWgene <- glmLRT(fitGene, contrast=pairwise.contrasts[,"TTvTW"])
GxEgene <- glmLRT(fitGene, contrast=pairwise.contrasts[,"GxE"])
annovGene <- glmLRT(fitGene, contrast=pairwise.contrasts)

STvSWintergenic <- glmLRT(fitIntergenic, contrast=pairwise.contrasts[,"STvSW"])
STvTTintergenic <- glmLRT(fitIntergenic, contrast=pairwise.contrasts[,"STvTT"])
SWvTWintergenic <- glmLRT(fitIntergenic, contrast=pairwise.contrasts[,"SWvTW"])
TTvTWintergenic <- glmLRT(fitIntergenic, contrast=pairwise.contrasts[,"TTvTW"])
GxEintergenic <- glmLRT(fitIntergenic, contrast=pairwise.contrasts[,"GxE"])
annovIntergenic <- glmLRT(fitIntergenic, contrast=pairwise.contrasts)

##################################################################
### Further information on significant DMs #######################
##################################################################
#############
### STvSW ###
#############
topTags(STvSWpromoter)
summary(decideTests(STvSWpromoter))
summary(decideTests(STvSWgene))
summary(decideTests(STvSWintergenic))
### Write to files ###
### Promoter ###
up <- decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) > 0),]
down <- decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) < 0),]
all <- decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),]
write.table (names(all), "STvSWpromoterDM.csv", sep=",")
up1 <- yPromoter[row.names(yPromoter$counts) %in% names(up),]
down1 <- yPromoter[row.names(yPromoter$counts) %in% names(down),]
write.table (up1$counts, "STvSWpromoterDMup.csv", sep=",")
write.table (down1$counts, "STvSWpromoterDMdown.csv", sep=",")
### Gene ###
up <- decideTests(STvSWgene)[which(decideTests(STvSWgene) > 0),]
down <- decideTests(STvSWgene)[which(decideTests(STvSWgene) < 0),]
all <- decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),]
write.table (names(all), "STvSWgeneDM.csv", sep=",")
up1 <- yGene[row.names(yGene$counts) %in% names(up),]
down1 <- yGene[row.names(yGene$counts) %in% names(down),]
write.table (up1$counts, "STvSWgeneDMup.csv", sep=",")
write.table (down1$counts, "STvSWgeneDMdown.csv", sep=",")
### Intergenic ###
up <- decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) > 0),]
down <- decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) < 0),]
all <- decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),]
write.table (names(all), "STvSWintergenicDM.csv", sep=",")
up1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(up),]
down1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(down),]
write.table (up1$counts, "STvSWintergenicDMup.csv", sep=",")
write.table (down1$counts, "STvSWintergenicDMdown.csv", sep=",")

#############
### TTvTW ###
#############
topTags(TTvTWpromoter)
summary(decideTests(TTvTWpromoter))
summary(decideTests(TTvTWgene))
summary(decideTests(TTvTWintergenic))
### Write to files ###
### Promoter ###
up <- decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) > 0),]
down <- decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) < 0),]
all <- decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),]
write.table (names(all), "TTvTWpromoterDM.csv", sep=",")
up1 <- yPromoter[row.names(yPromoter$counts) %in% names(up),]
down1 <- yPromoter[row.names(yPromoter$counts) %in% names(down),]
write.table (up1$counts, "TTvTWpromoterDMup.csv", sep=",")
write.table (down1$counts, "TTvTWpromoterDMdown.csv", sep=",")
### Gene ###
up <- decideTests(TTvTWgene)[which(decideTests(TTvTWgene) > 0),]
down <- decideTests(TTvTWgene)[which(decideTests(TTvTWgene) < 0),]
all <- decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),]
write.table (names(all), "TTvTWgeneDM.csv", sep=",")
up1 <- yGene[row.names(yGene$counts) %in% names(up),]
down1 <- yGene[row.names(yGene$counts) %in% names(down),]
write.table (up1$counts, "TTvTWgeneDMup.csv", sep=",")
write.table (down1$counts, "TTvTWgeneDMdown.csv", sep=",")
### Intergenic ###
up <- decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) > 0),]
down <- decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) < 0),]
all <- decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),]
write.table (names(all), "TTvTWintergenicDM.csv", sep=",")
up1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(up),]
down1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(down),]
write.table (up1$counts, "TTvTWintergenicDMup.csv", sep=",")
write.table (down1$counts, "TTvTWintergenicDMdown.csv", sep=",")

#############
### STvTT ###
#############
topTags(STvTTpromoter)
summary(decideTests(STvTTpromoter))
summary(decideTests(STvTTgene))
summary(decideTests(STvTTintergenic))
### Write to files ###
### Promoter ###
up <- decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) > 0),]
down <- decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) < 0),]
all <- decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),]
write.table (names(all), "STvTTpromoterDM.csv", sep=",")
up1 <- yPromoter[row.names(yPromoter$counts) %in% names(up),]
down1 <- yPromoter[row.names(yPromoter$counts) %in% names(down),]
write.table (up1$counts, "STvTTpromoterDMup.csv", sep=",")
write.table (down1$counts, "STvTTpromoterDMdown.csv", sep=",")
### Gene ###
up <- decideTests(STvTTgene)[which(decideTests(STvTTgene) > 0),]
down <- decideTests(STvTTgene)[which(decideTests(STvTTgene) < 0),]
all <- decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),]
write.table (names(all), "STvTTgeneDM.csv", sep=",")
up1 <- yGene[row.names(yGene$counts) %in% names(up),]
down1 <- yGene[row.names(yGene$counts) %in% names(down),]
write.table (up1$counts, "STvTTgeneDMup.csv", sep=",")
write.table (down1$counts, "STvTTgeneDMdown.csv", sep=",")
### Intergenic ###
up <- decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) > 0),]
down <- decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) < 0),]
all <- decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),]
write.table (names(all), "STvTTintergenicDM.csv", sep=",")
up1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(up),]
down1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(down),]
write.table (up1$counts, "STvTTintergenicDMup.csv", sep=",")
write.table (down1$counts, "STvTTintergenicDMdown.csv", sep=",")

#############
### SWvTW ###
#############
topTags(SWvTWpromoter)
summary(decideTests(SWvTWpromoter))
summary(decideTests(SWvTWgene))
summary(decideTests(SWvTWintergenic))
### Write to files ###
### Promoter ###
up <- decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) > 0),]
down <- decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) < 0),]
all <- decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),]
write.table (names(all), "SWvTWpromoterDM.csv", sep=",")
up1 <- yPromoter[row.names(yPromoter$counts) %in% names(up),]
down1 <- yPromoter[row.names(yPromoter$counts) %in% names(down),]
write.table (up1$counts, "SWvTWpromoterDMup.csv", sep=",")
write.table (down1$counts, "SWvTWpromoterDMdown.csv", sep=",")
### Gene ###
up <- decideTests(SWvTWgene)[which(decideTests(SWvTWgene) > 0),]
down <- decideTests(SWvTWgene)[which(decideTests(SWvTWgene) < 0),]
all <- decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),]
write.table (names(all), "SWvTWgeneDM.csv", sep=",")
up1 <- yGene[row.names(yGene$counts) %in% names(up),]
down1 <- yGene[row.names(yGene$counts) %in% names(down),]
write.table (up1$counts, "SWvTWgeneDMup.csv", sep=",")
write.table (down1$counts, "SWvTWgeneDMdown.csv", sep=",")
### Intergenic ###
up <- decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) > 0),]
down <- decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) < 0),]
all <- decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),]
write.table (names(all), "SWvTWintergenicDM.csv", sep=",")
up1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(up),]
down1 <- yIntergenic[row.names(yIntergenic$counts) %in% names(down),]
write.table (up1$counts, "SWvTWintergenicDMup.csv", sep=",")
write.table (down1$counts, "SWvTWintergenicDMdown.csv", sep=",")

#############
### annov ###
#############
topTags(annovPromoter)
summary(decideTests(annovPromoter))
summary(decideTests(annovGene))
summary(decideTests(annovIntergenic))
### Promoter
significantDM <- yPromoter[as.vector(rownames(topTags(annovPromoter, p.value=0.05, n=823)$table)),]
head(significantDM$counts)
significantDM <- as.data.frame(significantDM$counts)
write.table(significantDM, "significant.Annova.promoter.new.DM.all.csv", sep=",")
### Gene
significantDM <- yGene[as.vector(rownames(topTags(annovGene, p.value=0.05, n=7166)$table)),]
head(significantDM$counts)
significantDM <- as.data.frame(significantDM$counts)
write.table(significantDM, "significant.Annova.gene.new.DM.all.csv", sep=",")
### intergenetic
significantDM <- yIntergenic[as.vector(rownames(topTags(annovIntergenic, p.value=0.05, n=76050)$table)),]
head(significantDM$counts)
significantDM <- as.data.frame(significantDM$counts)
write.table(significantDM, "significant.Annova.intergenic.new.DM.all.csv", sep=",")

#############
### GxE   ###
#############
topTags(GxEpromoter)
summary(decideTests(GxEpromoter))
summary(decideTests(GxEgene))
summary(decideTests(GxEintergenic))
### Promoter
significantDM <- yPromoter[as.vector(rownames(topTags(GxEpromoter, p.value=0.05, n=18)$table)),]
head(significantDM$counts)
significantDM <- as.data.frame(significantDM$counts)
write.table(significantDM, "significant.GxE.promoter.new.DM.all.csv", sep=",")
### Gene
significantDM <- yGene[as.vector(rownames(topTags(GxEgene, p.value=0.05, n=63)$table)),]
head(significantDM$counts)
significantDM <- as.data.frame(significantDM$counts)
write.table(significantDM, "significant.GxE.gene.new.DM.all.csv", sep=",")
### intergenetic
significantDM <- yIntergenic[as.vector(rownames(topTags(GxEintergenic, p.value=0.05, n=485)$table)),]
head(significantDM$counts)
significantDM <- as.data.frame(significantDM$counts)
write.table(significantDM, "significant.GxE.intergenic.new.DM.all.csv", sep=",")

#############################################################
### Overlaps ################################################
#############################################################
###STvSW (up-regulated, down-regulated, all)
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) > 0),])), row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) > 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) < 0),])), row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) < 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),])), row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),]))))

###TTvTW (up-regulated, down-regulated, all)
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) > 0),])), row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) > 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) < 0),])), row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) < 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),])), row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),]))))

###STvTT (up-regulated, down-regulated, all)
summary(intersect(row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) > 0),])), row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) > 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) < 0),])), row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) < 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),])), row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),]))))

###SWvTW (up-regulated, down-regulated, all)
summary(intersect(row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) > 0),])), row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) > 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) < 0),])), row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) < 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),])), row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),]))))

###Anova (up-regulated, down-regulated, all)
summary(intersect(row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),])), row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),]))))

###GxE (up-regulated, down-regulated, all)
summary(intersect(row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) > 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) > 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) < 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) < 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),]))))


###Promoter
###Pairwise STvSW vs. Others (promoter)
summary(intersect(row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),])), row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),])), row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),])), row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),])), row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),])), row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWpromoter)[which(decideTests(STvSWpromoter) != 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),]))))
###Pairwise TTvTW vs. Others (promoter)
summary(intersect(row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWpromoter)[which(decideTests(TTvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),]))))
###Pairwise STvTT vs. Others (promoter)
summary(intersect(row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),])), row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),])), row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),])), row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTpromoter)[which(decideTests(STvTTpromoter) != 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),]))))
###Pairwise SWvTW vs. Others (promoter)
summary(intersect(row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWpromoter)[which(decideTests(SWvTWpromoter) != 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),]))))
###Pairwise Anova vs. Others (promoter)
summary(intersect(row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),])), row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(annovPromoter)[which(decideTests(annovPromoter) != 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),]))))
###Pairwise GxE vs. Others (promoter)
summary(intersect(row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),])), row.names(as.data.frame(decideTests(GxEpromoter)[which(decideTests(GxEpromoter) != 0),]))))

###Gene
###Pairwise STvSW vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),])), row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),])), row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),])), row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),])), row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),])), row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWgene)[which(decideTests(STvSWgene) != 0),])), row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),]))))
###Pairwise TTvTW vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),])), row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),])), row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),])), row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),])), row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWgene)[which(decideTests(TTvTWgene) != 0),])), row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),]))))
###Pairwise STvTT vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),])), row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),])), row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),])), row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTgene)[which(decideTests(STvTTgene) != 0),])), row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),]))))
###Pairwise SWvTW vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),])), row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),])), row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWgene)[which(decideTests(SWvTWgene) != 0),])), row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),]))))
###Pairwise Anova vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),])), row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(annovGene)[which(decideTests(annovGene) != 0),])), row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),]))))
###Pairwise GxE vs. Others (gene)
summary(intersect(row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),])), row.names(as.data.frame(decideTests(GxEgene)[which(decideTests(GxEgene) != 0),]))))

###Intergenic
###Pairwise STvSW vs. Others (intergenic)
summary(intersect(row.names(as.data.frame(decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),])), row.names(as.data.frame(decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),])), row.names(as.data.frame(decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),])), row.names(as.data.frame(decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),])), row.names(as.data.frame(decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),])), row.names(as.data.frame(decideTests(annovIntergenic)[which(decideTests(annovIntergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvSWintergenic)[which(decideTests(STvSWintergenic) != 0),])), row.names(as.data.frame(decideTests(GxEintergenic)[which(decideTests(GxEintergenic) != 0),]))))
###Pairwise TTvTW vs. Others (intergenic)
summary(intersect(row.names(as.data.frame(decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(annovIntergenic)[which(decideTests(annovIntergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(TTvTWintergenic)[which(decideTests(TTvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(GxEintergenic)[which(decideTests(GxEintergenic) != 0),]))))
###Pairwise STvTT vs. Others (intergenic)
summary(intersect(row.names(as.data.frame(decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),])), row.names(as.data.frame(decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),])), row.names(as.data.frame(decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),])), row.names(as.data.frame(decideTests(annovIntergenic)[which(decideTests(annovIntergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(STvTTintergenic)[which(decideTests(STvTTintergenic) != 0),])), row.names(as.data.frame(decideTests(GxEintergenic)[which(decideTests(GxEintergenic) != 0),]))))
###Pairwise SWvTW vs. Others (intergenic)
summary(intersect(row.names(as.data.frame(decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(annovIntergenic)[which(decideTests(annovIntergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(SWvTWintergenic)[which(decideTests(SWvTWintergenic) != 0),])), row.names(as.data.frame(decideTests(GxEintergenic)[which(decideTests(GxEintergenic) != 0),]))))
###Pairwise Anova vs. Others (intergenic)
summary(intersect(row.names(as.data.frame(decideTests(annovIntergenic)[which(decideTests(annovIntergenic) != 0),])), row.names(as.data.frame(decideTests(annovIntergenic)[which(decideTests(annovIntergenic) != 0),]))))
summary(intersect(row.names(as.data.frame(decideTests(annovIntergenic)[which(decideTests(annovIntergenic) != 0),])), row.names(as.data.frame(decideTests(GxEintergenic)[which(decideTests(GxEintergenic) != 0),]))))
###Pairwise GxE vs. Others (intergenic)
summary(intersect(row.names(as.data.frame(decideTests(GxEintergenic)[which(decideTests(GxEintergenic) != 0),])), row.names(as.data.frame(decideTests(GxEintergenic)[which(decideTests(GxEintergenic) != 0),]))))

#############################################################
### Heatmap #################################################
#############################################################
###Gene
sGxEgene <- as.data.frame(yGene[as.vector(rownames(topTags(GxEgene, p.value=0.05, n=63)$table)),]$counts)
###Data structuring
sGxEgene$ST <- (sGxEgene$`ST1-Me`/(sGxEgene$`ST1-Me` + sGxEgene$`ST1-Un`) +
                  sGxEgene$`ST2-Me`/(sGxEgene$`ST2-Me` + sGxEgene$`ST2-Un`))/2
sGxEgene$SW <- (sGxEgene$`SW1-Me`/(sGxEgene$`SW1-Me` + sGxEgene$`SW1-Un`) +
                  sGxEgene$`SW2-Me`/(sGxEgene$`SW2-Me` + sGxEgene$`SW2-Un`))/2
sGxEgene$TT <- (sGxEgene$`TT1-Me`/(sGxEgene$`TT1-Me` + sGxEgene$`TT1-Un`) +
                  sGxEgene$`TT2-Me`/(sGxEgene$`TT2-Me` + sGxEgene$`TT2-Un`))/2
sGxEgene$TW <- (sGxEgene$`TW1-Me`/(sGxEgene$`TW1-Me` + sGxEgene$`TW1-Un`) +
                  sGxEgene$`TW2-Me`/(sGxEgene$`TW2-Me` + sGxEgene$`TW2-Un`))/2

sGxEgene <- subset(sGxEgene, select=c('ST','SW','TT','TW'))
sGxEgene <- sGxEgene[,c(2,4,1,3)]
head(sGxEgene)
heatmap(x=as.matrix(sGxEgene),col= colorRampPalette(brewer.pal(8, "Blues"))(25))
legend(x="topleft", legend=c("min", "avg.", "max"), 
       fill=colorRampPalette(brewer.pal(8, "Blues"))(3))

rows.cor <- cor(t(sGxEgene), use = "pairwise.complete.obs", method = "spearman")
hclust.row <- hclust(as.dist(1-rows.cor))
cols.cor <- cor(sGxEgene, use = "pairwise.complete.obs", method = "spearman")
hclust.col <- hclust(as.dist(1-cols.cor))

library("pheatmap")
pheatmap(
  as.matrix(sGxEgene), scale = "row", 
  clustering_distance_cols = as.dist(1 - cols.cor),
  clustering_distance_rows = as.dist(1 - rows.cor),
  show_rownames = F
)

c1 <- sGxEgene
c1$gene <- rownames(c1)
c1_melt = melt(subset(c1, select=c('SW','TW','ST','TT','gene')), id.vars = 'gene')
ggplot(c1_melt, aes(x=variable, y=log(value))) + 
  geom_line(aes(color=gene, group=gene)) +
  theme_classic()# +
#theme(legend.position="none")



#############################################################
###Promoter
sGxEprom <- as.data.frame(yPromoter[as.vector(rownames(topTags(GxEpromoter, p.value=0.05, n=18)$table)),]$counts)
###Data structuring
sGxEprom$ST <- (sGxEprom$`ST1-Me`/(sGxEprom$`ST1-Me` + sGxEprom$`ST1-Un`) +
                  sGxEprom$`ST2-Me`/(sGxEprom$`ST2-Me` + sGxEprom$`ST2-Un`))/2
sGxEprom$SW <- (sGxEprom$`SW1-Me`/(sGxEprom$`SW1-Me` + sGxEprom$`SW1-Un`) +
                  sGxEprom$`SW2-Me`/(sGxEprom$`SW2-Me` + sGxEprom$`SW2-Un`))/2
sGxEprom$TT <- (sGxEprom$`TT1-Me`/(sGxEprom$`TT1-Me` + sGxEprom$`TT1-Un`) +
                  sGxEprom$`TT2-Me`/(sGxEprom$`TT2-Me` + sGxEprom$`TT2-Un`))/2
sGxEprom$TW <- (sGxEprom$`TW1-Me`/(sGxEprom$`TW1-Me` + sGxEprom$`TW1-Un`) +
                  sGxEprom$`TW2-Me`/(sGxEprom$`TW2-Me` + sGxEprom$`TW2-Un`))/2

sGxEprom <- subset(sGxEprom, select=c('ST','SW','TT','TW'))
sGxEprom <- sGxEprom[,c(2,4,1,3)]
head(sGxEprom)
heatmap(x=as.matrix(sGxEprom),col= colorRampPalette(brewer.pal(8, "Blues"))(25))
legend(x="topleft", legend=c("min", "avg.", "max"), 
       fill=colorRampPalette(brewer.pal(8, "Blues"))(3))

rows.cor <- cor(t(sGxEprom), use = "pairwise.complete.obs", method = "spearman")
hclust.row <- hclust(as.dist(1-rows.cor))
cols.cor <- cor(sGxEprom, use = "pairwise.complete.obs", method = "spearman")
hclust.col <- hclust(as.dist(1-cols.cor))

library("pheatmap")
pheatmap(
  as.matrix(sGxEprom), scale = "row", 
  clustering_distance_cols = as.dist(1 - cols.cor),
  clustering_distance_rows = as.dist(1 - rows.cor),
  show_rownames = F
)

c1 <- sGxEprom
c1$gene <- rownames(c1)
c1_melt = melt(subset(c1, select=c('SW','TW','ST','TT','gene')), id.vars = 'gene')
ggplot(c1_melt, aes(x=variable, y=log(value))) + 
  geom_line(aes(color=gene, group=gene)) +
  theme_classic()# +
#theme(legend.position="none")

#############################################################
### Growth Hormone Gene Expression Differences ##############
### Needs to be performed before removing low expressed genes
z <- c("LOC109893213","LOC109898300","LOC109877434","LOC109889150",
       "LOC109877853","LOC109892335","LOC109868115","LOC109873840",
       "LOC109896160","LOC109873964", "transgene")
gh <- ypr[row.names(ypr$counts) %in% z,]
head(gh$counts, n=40)

#############################################################
### Transposable Elements (PiggyBAC) ########################
x <- c("LOC109902658","LOC109872064","LOC109872199","LOC109906238","LOC109899170","
       LOC109891614","LOC109878482","LOC109875800","LOC109870067","LOC109910161","LOC109906768","
       LOC109905967","LOC109904664","LOC109904587","LOC109898877","LOC109895269","LOC109889549","
       LOC109877893","LOC109876121","LOC109873605","LOC109873580")
piggy <- ypr[row.names(ypr$counts) %in% x,]
piggy$counts

#############################################################
### insulin growth factors           ########################
u <- c("igf1","LOC109907930","LOC109896674","LOC109867245")
igf <- ypr[row.names(ypr$counts) %in% u,]
igf$counts

#############################################################
### Check for specific genes 
significantDM[which(rownames(significantDM)=="OkisSdy"),]
sdy <- yall[which(yall$genes$Chr == "OkisSdY"),]
sdy$counts
ggplot(sdy$counts)